#include "phidget22extra/phidgethelpers.h"

PHIDAPI const char *
getErrorStr(PhidgetReturnCode code) {
	PhidgetReturnCode res;
	const char *str;

	res = Phidget_getErrorDescription(code, &str);
	if (res != EPHIDGET_OK)
		return ("<unknown return code>");
	return (str);
}

PHIDAPI int
getDeviceVersion(PhidgetHandle phid) {
	int ver;

	if (Phidget_getDeviceVersion(phid, &ver) != 0)
		return (-1);
	return (ver);
}

PHIDAPI int
getDeviceSerialNumber(PhidgetHandle phid) {
	int sn;

	if (Phidget_getDeviceSerialNumber(phid, &sn) != 0)
		return (-1);
	return (sn);
}

PHIDAPI const char *
getDeviceName(PhidgetHandle phid) {
	const char *res;

	if (Phidget_getDeviceName(phid, &res) != 0)
		return ("<invalid phidget>");
	return (res);
}

PHIDAPI const char *
getDeviceClassName(PhidgetHandle phid) {
	const char *res;

	if (Phidget_getDeviceClassName(phid, &res) != 0)
		return ("<invalid phidget>");
	return (res);
}

PHIDAPI const char *
getChannelClassName(PhidgetHandle phid) {
	const char *res;

	if (Phidget_getChannelClassName(phid, &res) != 0)
		return ("<invalid phidget>");
	return (res);
}

PHIDAPI const char *
getDeviceLabel(PhidgetHandle phid) {
	const char *res;

	if (Phidget_getDeviceLabel(phid, &res) != 0)
		return ("<invalid phidget>");
	return (res);
}

PHIDAPI Phidget_DeviceID
getDeviceID(PhidgetHandle phid) {
	Phidget_DeviceID did;

	if (Phidget_getDeviceID(phid, &did) != 0)
		return (PHIDID_NOTHING);
	return (did);
}

PHIDAPI Phidget_DeviceClass
getDeviceClass(PhidgetHandle phid) {
	Phidget_DeviceClass dc;

	if (Phidget_getDeviceClass(phid, &dc) != 0)
		return (PHIDCLASS_NOTHING);
	return (dc);
}

PHIDAPI Phidget_ChannelClass
getChannelClass(PhidgetHandle phid) {
	Phidget_ChannelClass dc;

	if (Phidget_getChannelClass(phid, &dc) != 0)
		return (PHIDCHCLASS_NOTHING);
	return (dc);
}

PHIDAPI int
isChannel(PhidgetHandle phid) {
	int res;

	if (Phidget_getIsChannel(phid, &res) != 0)
		return (0);
	return (res);
}

PHIDAPI int
getChannel(PhidgetHandle phid) {
	int res;

	if (Phidget_getChannel(phid, &res) != 0)
		return (-1);
	return (res);
}

PHIDAPI int
isRemote(PhidgetHandle phid) {
	int res;

	if (Phidget_getIsRemote(phid, &res) != 0)
		return (-1);
	return (res);
}

PHIDAPI int
isHubPortDevice(PhidgetHandle phid) {
	int res;

	if (Phidget_getIsHubPortDevice(phid, &res) != 0)
		return (-1);
	return (res);
}

PHIDAPI int
getHubPort(PhidgetHandle phid) {
	int res;

	if (Phidget_getHubPort(phid, &res) != 0)
		return (-1);
	return (res);
}